@@ -1,20 +1,20 @@
 from youtube_easy_api.easy_wrapper import *
 
 PROJECT_PATH = os.path.abspath(os.path.join(os.path.abspath(__file__), os.pardir))
-CREDENTIALS_PATH = PROJECT_PATH
+CREDENTIALS_PATH = '../../../Secrets/YouTube'
 
 
 def test_get_video_details_01():
     easy_wrapper = YoutubeEasyWrapper()
     easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
-    metadata = easy_wrapper.get_video_details(video_id='LsK-xG1cLY')
+    metadata = easy_wrapper.get_video_metadata(video_id='LsK-xG1cLY')
     assert metadata['comments'][0] == 'Your channel has saved me a looooooot of time. Thanks!'
 
 
 def test_get_video_details_02():
     easy_wrapper = YoutubeEasyWrapper()
     easy_wrapper.initialize(credentials_path=CREDENTIALS_PATH)
-    metadata = easy_wrapper.get_video_details(video_id='rdjnkb4ONWk')
+    metadata = easy_wrapper.get_video_metadata(video_id='rdjnkb4ONWk')
     print(metadata['statistics']['likeCount'])
     assert metadata['title'] == 'The Pink Panther Show Episode 59 - Slink Pink'
 
@@ -30,5 +30,3 @@ def test_search_videos_by_keyword():
     order_id = 1
     video_id = results[order_id]['video_id']
     assert video_id == '_uQrJ0TkZlc'
-
-test_get_video_details_02()
\ No newline at end of file
